if [ -d usr/share/applications ]; then
  /usr/bin/update-desktop-database -q /usr/share/applications >/dev/null 2>&1
fi

if [ -d usr/share/mime ]; then
  /usr/bin/update-mime-database /usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache /usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -d usr/share/glib-2.0/schemas ]; then
  /usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas >/dev/null 2>&1
fi
( cd usr/lib64 ; rm -rf libgnome-bluetooth.so )
( cd usr/lib64 ; ln -sf libgnome-bluetooth.so.13 libgnome-bluetooth.so )
( cd usr/lib64 ; rm -rf libgnome-bluetooth.so.13 )
( cd usr/lib64 ; ln -sf libgnome-bluetooth.so.13.1.0 libgnome-bluetooth.so.13 )
